==> haskell-hls-class-plugin-2.1.0.0-99-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-class-plugin-2.1.0.0-5sJAxZVqfGp69kmHCPsVc3
key:                  hls-class-plugin-2.1.0.0-5sJAxZVqfGp69kmHCPsVc3
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  27c9e9d41cff384d9a4fa26decd1d02a
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.1.0.0-5sJAxZVqfGp69kmHCPsVc3
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-3o8MjPiNQTlLg74BSenHLy ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
    ghcide-2.1.0.0-BlCpiz4ZHvtIqUTiKV6UyX
    hls-graph-2.1.0.0-5t3ebukJcC8H3T2BKlhdh9
    hls-plugin-api-2.1.0.0-IyHsVCiLch7D25xEM5t6Zs
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-class-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-class-plugin-2.1.0.0-1r1i8A4P9z0By3SueT6nan
key:                  hls-class-plugin-2.1.0.0-1r1i8A4P9z0By3SueT6nan
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  33e03fb8a80fd41f734eda86eee0303c
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.1.0.0-1r1i8A4P9z0By3SueT6nan
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-IkudFHstV64EKMSGT8IWWb ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-exactprint-1.7.1.0-Icc6yarV61YJwCVVP7qqo9
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-graph-2.1.0.0-LgEicARMXCt6QmF6Vp3LRx
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
